[ljcom] r10599: LJSUP-8948: June 2011 header for cyr use...
Committer: gariev
LJSUP-8948: June 2011 header for cyr usersLJSUP-8949: June 2011 header for non cyr users
U trunk/cgi-bin/LJ/Hooks/Homepage.pm
Modified: trunk/cgi-bin/LJ/Hooks/Homepage.pm
===================================================================
--- trunk/cgi-bin/LJ/Hooks/Homepage.pm 2011-06-02 07:07:50 UTC (rev 10598)
+++ trunk/cgi-bin/LJ/Hooks/Homepage.pm 2011-06-02 07:51:58 UTC (rev 10599)
@@ -50,24 +50,16 @@
my $is_sup = LJ::SUP->is_remote_sup();
my $time = time();
- ## for non-cyr, till 22.05.2011 23:59 GMT
- if (!$is_sup && $time < 1306108799) {
- LJ::need_res("stc/reskining/2011/may/noncyr/header_heal.css");
- my $text = LJ::Lang::ml('reskining.may2011.noncyr.till23');
- LJ::CleanHTML::clean(\$text, { allow => [ 'a' ] }); ## to expand <lj-user> tags and to add <a> tags
- return qq[<dl class="b-reskining-about"><dt></dt><dd>$text</dd></dl>];
- }
-
if (!$is_sup) {
- ## LJSUP-8753: May header US
- LJ::need_res("stc/reskining/2011/may/noncyr/header.css");
- my $text = LJ::Lang::ml('reskining.may2011.noncyr');
+ ## LJSUP-8949: June 2011 header for non cyr users
+ LJ::need_res("stc/reskining/2011/june/noncyr/header.css");
+ my $text = LJ::Lang::ml('reskining.june2011.noncyr');
LJ::CleanHTML::clean(\$text, { allow => [ 'a' ] }); ## to expand <lj-user> tags and to add <a> tags
return qq[<dl class="b-reskining-about"><dt></dt><dd>$text</dd></dl>];
} else {
- ##LJSUP-8742: May header for cyr users
- LJ::need_res("stc/reskining/2011/may/cyr/header.css");
- my $text = LJ::Lang::ml('reskining.may2011.enze');
+ ## LJSUP-8948: June 2011 header for cyr users
+ LJ::need_res("stc/reskining/2011/june/cyr/header.css");
+ my $text = LJ::Lang::ml('reskining.june2011.cyr');
LJ::CleanHTML::clean(\$text, { allow => [ 'a' ] }); ## to add <a> tags
return qq[<dl class="b-reskining-about"><dt></dt><dd>$text</dd></dl>];
}
